@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2011 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: m3Func.php 4471 2011-11-26 10:19:40Z fishbone $
+ * @version    SVN: $Id: m3Func.php 4606 2012-01-21 14:21:00Z fishbone $
  * @link       http://www.magic3.org
  */
 /**
@@ -80,6 +80,31 @@ function array_insert($srcArray, $insertArray, $position = -1)
     // 配列を結合
     return array_merge($srcArray, $lastArray);
 }
+/**
+ * トリミング文字列分割
+ *
+ * @param string  $delimiter	区切り文字列
+ * @param string  $str			変換元文字列
+ * @param string  $charList		トリミングする文字のリスト
+ * @return array				分割した文字列
+ */
+function trimExplode($delimiter, $str, $charList = '')
+{
+	$srcArray = explode($delimiter, $str);
+	$destArray = array();
+	if (empty($charList)){
+		for ($i = 0; $i < count($srcArray); $i++){
+			$value = trim($srcArray[$i]);
+			if (!empty($value)) $destArray[] = $value;
+		}
+	} else {
+		for ($i = 0; $i < count($srcArray); $i++){
+			$value = trim($srcArray[$i], $charList);
+			if (!empty($value)) $destArray[] = $value;
+		}
+	}
+	return $destArray;
+}
 /**
  * パスワードを生成する
  *
@@ -611,7 +636,6 @@ function convertFromHtmlEntity($src)
  */
 function _replace_nottag_callback($matchData)
 {
-//echo $matchData[0] .'  --';
 	return htmlentities($matchData[0], ENT_COMPAT, M3_HTML_CHARSET);
 }
 /**
