@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: envManager.php 4298 2011-09-06 03:02:06Z fishbone $
+ * @version    SVN: $Id: envManager.php 4499 2011-12-12 13:10:51Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/version.php');	// システムバージョンクラス
@@ -1155,6 +1155,18 @@ class EnvManager extends Core
 
 		return $this->getWidgetsPath() . '/' . $widgetId . '/include/iwidgets/' . $iWidgetId . DIRECTORY_SEPARATOR . 'include' . DIRECTORY_SEPARATOR . 'db';
 	}
+	/**
+	 * 現在処理中のインナーウィジェットのdbディレクトリへのパスを取得
+	 *
+	 * 例) /var/www/html/magic3/widgets/xxxxx/include/iwidgets/yyyyy/include/container
+	 */
+	public function getCurrentIWidgetContainerPath()
+	{
+		// ウィジェットIDとインナーウィジェットIDを取り出す
+		list($widgetId, $iWidgetId) = explode(M3_WIDGET_ID_SEPARATOR, $this->currentIWidgetId);
+
+		return $this->getWidgetsPath() . '/' . $widgetId . '/include/iwidgets/' . $iWidgetId . DIRECTORY_SEPARATOR . 'include' . DIRECTORY_SEPARATOR . 'container';
+	}
 	/**
 	 * 現在処理中のウィジェット
 	 */
