@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2011 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: insert_std.sql 4614 2012-01-25 00:34:23Z fishbone $
+-- * @version    SVN: $Id: insert_std.sql 4702 2012-02-19 14:59:56Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -333,7 +333,8 @@ INSERT INTO photo_config
 ('photo_list_item_count',  '24',                '画像一覧表示項目数',         9),
 ('photo_list_order',        '0',         '画像一覧表示順',                         10),
 ('photo_title_short_length',  '10',                '画像タイトル(略式)文字数',         11),
-('photo_category_password', '0',                '画像カテゴリーのパスワード制限',             12);
+('photo_category_password', '0',                '画像カテゴリーのパスワード制限',             12),
+('thumbnail_crop',      '1',                'サムネール画像切り取り',         13);
 
 -- --------------------------------------------------------------------------------------------------
 -- 携帯クイズ王ウィジェット用
