@@ -9,7 +9,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: m3admin1.5.4.js 4689 2012-02-16 15:34:51Z fishbone $
+ * @version    SVN: $Id: m3admin1.5.5.js 4742 2012-03-08 04:01:17Z fishbone $
  * @link       http://www.magic3.org
  */
 // 親ウィンドウを更新
@@ -188,3 +188,80 @@ function m3_setHtmlEditor(id, isMobile)
 	oFCKeditor.Value	= 'This is some <strong>sample text<\/strong>. You are using <a href="http://www.fckeditor.net/">FCKeditor<\/a>.';
 	oFCKeditor.ReplaceTextarea();
 }
+/**
+ * 画面操作用スライド開閉メニューバー
+ */
+(function($){
+	$.fn.m3SlideMenubar = function(givenOpts){
+		opts = $.extend({
+			position: 'top',			// panel position 'top' or 'bottom'
+			height: '80px',				// set the height of the panel
+			speed: 'normal',			// 'slow', 'normal', 'fast', or number in milliseconds
+			touchPanel: false,			// mouse click operation than mouse hover
+			openBtn: '.open',			// open button id or class inside 'slidetrigger' div
+			closeBtn: '.close',			// close button id or class inside 'slidetrigger' div
+			slideTrigger: '#slidetrigger'	// trigger id or class
+		}, givenOpts);
+
+		// refers to the selector 'm3SlideMenubar'
+		var $this = $(this);
+
+		// vars needed to pass args to animate method
+		var containerpadding;
+		var aniOpenArgs = {};
+		var aniCloseArgs = {};
+
+		// add appropriate class names based on position
+		if (opts.position == 'top') {
+			$this.addClass('top');
+			$(opts.slideTrigger).addClass('top');
+			containerpadding = 'top';
+		} else {
+			$this.addClass('bottom');
+			$(opts.slideTrigger).addClass('bottom');
+			containerpadding = 'padding-bottom';
+		};
+
+		// set panel's height
+		$this.css('height', opts.height);
+
+		// remove the 'px' from the height string so we can calculate the container padding
+		var newpadding = opts.height.replace("px","");
+		newpadding = parseInt(opts.height) + 21;
+
+		aniOpenArgs[containerpadding] = newpadding;
+		aniCloseArgs[containerpadding] = 0;
+
+		if (opts.touchPanel){
+			// slide panel in and container down
+			$(opts.openBtn).click(function(){
+				$this.slideDown(opts.speed);
+				$(opts.slideTrigger).animate(aniOpenArgs, opts.speed);
+				$(opts.openBtn).css({'display':'none'});
+				$(opts.closeBtn).css({'display':'block'});
+				return false;
+			});
+			// slide panel out and container up
+			$(opts.closeBtn).click(function(){
+				$this.slideUp(opts.speed);
+				$(opts.slideTrigger).animate(aniCloseArgs, opts.speed);
+				$(opts.openBtn).css({'display':'block'});
+				$(opts.closeBtn).css({'display':'none'});
+				return false;
+			});
+		} else {
+			// slide panel in and container down
+			$(opts.openBtn).mouseover(function(){
+				$this.slideDown(opts.speed);
+				$(opts.slideTrigger).slideUp(opts.speed);
+				return false;
+			});
+			// slide panel out and container up
+			$this.hover(function(){},function(){
+				$this.slideUp(opts.speed);
+				$(opts.slideTrigger).slideDown(opts.speed);
+				return false;
+			});
+		}
+	};
+})(jQuery);
