@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainAnalyzegraphWidgetContainer.php 4159 2011-05-31 14:49:36Z fishbone $
+ * @version    SVN: $Id: admin_mainAnalyzegraphWidgetContainer.php 4160 2011-06-01 09:38:59Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainAnalyzeBaseWidgetContainer.php');
@@ -202,16 +202,20 @@ class admin_mainAnalyzegraphWidgetContainer extends admin_mainAnalyzeBaseWidgetC
 		
 		// ########## 上位URL一覧 ##########
 		// 総数を取得
-		switch ($this->graphType){
-			case 'pageview':		//ページビュー
-				$totalCount = $this->db->getUrlListCountByPageView($pathParam, $startDate, $endDate);
-				break;
-			case 'visit':			// 訪問数
-				$totalCount = $this->db->getUrlListCountByDailyCount(0/*訪問数*/, $pathParam, $startDate, $endDate);
-				break;
-			case 'visitor':			// 訪問者数
-				$totalCount = $this->db->getUrlListCountByDailyCount(1/*訪問者数*/, $pathParam, $startDate, $endDate);
-				break;
+		if (empty($endDate)){		// 集計済みデータがないとき
+			$totalCount = 0;
+		} else {
+			switch ($this->graphType){
+				case 'pageview':		//ページビュー
+					$totalCount = $this->db->getUrlListCountByPageView($pathParam, $startDate, $endDate);
+					break;
+				case 'visit':			// 訪問数
+					$totalCount = $this->db->getUrlListCountByDailyCount(0/*訪問数*/, $pathParam, $startDate, $endDate);
+					break;
+				case 'visitor':			// 訪問者数
+					$totalCount = $this->db->getUrlListCountByDailyCount(1/*訪問者数*/, $pathParam, $startDate, $endDate);
+					break;
+			}
 		}
 
 		// 表示するページ番号の修正
@@ -244,16 +248,18 @@ class admin_mainAnalyzegraphWidgetContainer extends admin_mainAnalyzeBaseWidgetC
 		if ($totalCount > 0) $this->tmpl->setAttribute('search_range', 'visibility', 'visible');// 検出範囲を表示
 		
 		// 一覧作成
-		switch ($this->graphType){
-			case 'pageview':		//ページビュー
-				$this->db->getUrlListByPageView($pathParam, $startDate, $endDate, $viewCount, $pageNo, array($this, 'pageViewLoop'));
-				break;
-			case 'visit':			// 訪問数
-				$this->db->getUrlListByDailyCount(0/*訪問数*/, $pathParam, $startDate, $endDate, $viewCount, $pageNo, array($this, 'pageViewLoop'));
-				break;
-			case 'visitor':			// 訪問者数
-				$this->db->getUrlListByDailyCount(1/*訪問者数*/, $pathParam, $startDate, $endDate, $viewCount, $pageNo, array($this, 'pageViewLoop'));
-				break;
+		if (!empty($endDate)){		// 集計済みデータがあるとき
+			switch ($this->graphType){
+				case 'pageview':		//ページビュー
+					$this->db->getUrlListByPageView($pathParam, $startDate, $endDate, $viewCount, $pageNo, array($this, 'pageViewLoop'));
+					break;
+				case 'visit':			// 訪問数
+					$this->db->getUrlListByDailyCount(0/*訪問数*/, $pathParam, $startDate, $endDate, $viewCount, $pageNo, array($this, 'pageViewLoop'));
+					break;
+				case 'visitor':			// 訪問者数
+					$this->db->getUrlListByDailyCount(1/*訪問者数*/, $pathParam, $startDate, $endDate, $viewCount, $pageNo, array($this, 'pageViewLoop'));
+					break;
+			}
 		}
 	}
 	/**
