@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainMenudefWidgetContainer.php 4257 2011-08-22 05:22:18Z fishbone $
+ * @version    SVN: $Id: admin_mainMenudefWidgetContainer.php 4569 2012-01-05 03:18:23Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -123,7 +123,7 @@ class admin_mainMenudefWidgetContainer extends admin_mainBaseWidgetContainer
 			$localeText['label_link_top'] = $this->_('Top');	// トップ
 			$localeText['label_input'] = $this->_('Input URL');	// URL任意設定
 			$localeText['label_page_id'] = $this->_('Page ID:');	// ページID：
-			$localeText['label_content'] = $this->_('Contents:');	// 表示コンテンツ：
+			$localeText['label_content'] = $this->_('General Contents:');	// 汎用コンテンツ：
 			$localeText['label_url'] = $this->_('URL');	// リンク先URL
 			$localeText['label_item_visible'] = $this->_('Item Control');	// 表示制御
 			$localeText['label_visible'] = $this->_('Visible');	// 公開
@@ -482,8 +482,21 @@ class admin_mainMenudefWidgetContainer extends admin_mainBaseWidgetContainer
 		}
 		
 		// リンク先設定用メニュー
-		$this->db->getPageIdList(array($this, 'pageSubIdLoop'), 1);// ウィジェットサブIDメニュー作成
-
+		//$this->db->getPageIdList(array($this, 'pageSubIdLoop'), 1);// ウィジェットサブIDメニュー作成
+		switch ($this->menuDeviceType){
+			case 0:			// PC用
+			default:
+				$defaultPageId = $this->gEnv->getDefaultPageId();
+				break;
+			case 1:			// 携帯用
+				$defaultPageId = $this->gEnv->getDefaultMobilePageId();
+				break;
+			case 2:			// スマートフォン用
+				$defaultPageId = $this->gEnv->getDefaultSmartphonePageId();
+				break;
+		}
+		$this->db->getPageSubIdList($defaultPageId, ''/*言語なし*/, array($this, 'pageSubIdLoop'));
+		
 		// メニュー項目タイプメニュー
 		$this->createItemTypeMenu();
 		
@@ -563,7 +576,11 @@ class admin_mainMenudefWidgetContainer extends admin_mainBaseWidgetContainer
 		$selected = '';
 		if ($fetchedRow['pg_id'] == $this->currentPageSubId) $selected = 'selected';	// 現在のページサブID
 		
-		$name = $fetchedRow['pg_id'] . ' - ' . $fetchedRow['pg_name'];
+		$contentType = $fetchedRow['pn_content_type'];
+		$name = $fetchedRow['pg_id'];
+		if (!empty($contentType)) $name .= '[' . $contentType . ']';
+		$name .= ' - ' . $fetchedRow['pg_name'];
+		
 		$row = array(
 			'value'    => $this->convertToDispString($fetchedRow['pg_id']),			// ページID
 			'name'     => $this->convertToDispString($name),			// ページ名
