@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_blog_mainConfigWidgetContainer.php 3614 2010-09-22 05:09:39Z fishbone $
+ * @version    SVN: $Id: admin_blog_mainConfigWidgetContainer.php 3953 2011-01-24 04:33:43Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_blog_mainBaseWidgetContainer.php');
@@ -61,10 +61,12 @@ class admin_blog_mainConfigWidgetContainer extends admin_blog_mainBaseWidgetCont
 		$receiveComment = ($request->trimValueOf('receive_comment') == 'on') ? 1 : 0;		// コメントを受け付けるかどうか
 		$useMultiBlog = ($request->trimValueOf('use_multi_blog') == 'on') ? 1 : 0;		// マルチブログ機能を使用するかどうか
 		$topContent = $request->valueOf('top_content');	// トップコンテンツ
+		$maxCommentLength = $request->valueOf('max_comment_length');	// コメント最大文字数
 		
 		if ($act == 'update'){		// 設定更新のとき
 			// 入力値のエラーチェック
 			$this->checkNumeric($entryViewCount, '記事表示順');
+			$this->checkNumeric($maxCommentLength, 'コメント最大文字数');
 			
 			if ($this->getMsgCount() == 0){			// エラーのないとき
 				$isErr = false;
@@ -81,6 +83,9 @@ class admin_blog_mainConfigWidgetContainer extends admin_blog_mainBaseWidgetCont
 				if (!$isErr){
 					if (!$this->_db->updateConfig(self::CF_RECEIVE_COMMENT, $receiveComment)) $isErr = true;// コメントを受け付けるかどうか
 				}
+				if (!$isErr){
+					if (!$this->_db->updateConfig(self::CF_MAX_COMMENT_LENGTH, $maxCommentLength)) $isErr = true;// コメント最大文字数
+				}
 				if (!$isErr){
 					if (!$this->_db->updateConfig(self::CF_USE_MULTI_BLOG, $useMultiBlog)) $isErr = true;// マルチブログ機能を使用するかどうか
 				}
@@ -97,6 +102,7 @@ class admin_blog_mainConfigWidgetContainer extends admin_blog_mainBaseWidgetCont
 				$entryViewOrder	= $this->_db->getConfig(self::CF_ENTRY_VIEW_ORDER);// 記事表示順
 				$categoryCount	= $this->_db->getConfig(self::CF_CATEGORY_COUNT);// カテゴリ数
 				$receiveComment	= $this->_db->getConfig(self::CF_RECEIVE_COMMENT);
+				$maxCommentLength = $this->_db->getConfig(self::CF_MAX_COMMENT_LENGTH);	// コメント最大文字数
 				$useMultiBlog = $this->_db->getConfig(self::CF_USE_MULTI_BLOG);// マルチブログ機能を使用するかどうか
 				$topContent = $this->_db->getConfig(self::CF_MULTI_BLOG_TOP_CONTENT);// マルチブログ時のトップコンテンツ
 			}
@@ -107,6 +113,8 @@ class admin_blog_mainConfigWidgetContainer extends admin_blog_mainBaseWidgetCont
 			$categoryCount	= $this->_db->getConfig(self::CF_CATEGORY_COUNT);// カテゴリ数
 			if (empty($categoryCount)) $categoryCount = self::DEFAULT_CATEGORY_COUNT;
 			$receiveComment	= $this->_db->getConfig(self::CF_RECEIVE_COMMENT);
+			$maxCommentLength = $this->_db->getConfig(self::CF_MAX_COMMENT_LENGTH);	// コメント最大文字数
+			if ($maxCommentLength == '') $maxCommentLength = self::DEFAULT_COMMENT_LENGTH;
 			$useMultiBlog = $this->_db->getConfig(self::CF_USE_MULTI_BLOG);// マルチブログ機能を使用するかどうか
 			if (is_null($useMultiBlog)) $useMultiBlog = '0';
 			$topContent = $this->_db->getConfig(self::CF_MULTI_BLOG_TOP_CONTENT);// マルチブログ時のトップコンテンツ
@@ -122,6 +130,7 @@ class admin_blog_mainConfigWidgetContainer extends admin_blog_mainBaseWidgetCont
 		$checked = '';
 		if ($receiveComment) $checked = 'checked';
 		$this->tmpl->addVar("_widget", "receive_comment", $checked);// コメントを受け付けるかどうか
+		$this->tmpl->addVar("_widget", "max_comment_length", $maxCommentLength);// コメント最大文字数
 		$checked = '';
 		if ($useMultiBlog) $checked = 'checked';
 		$this->tmpl->addVar("_widget", "use_multi_blog", $checked);// マルチブログ機能を使用するかどうか
