@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: photo_mainTopWidgetContainer.php 4611 2012-01-24 11:38:41Z fishbone $
+ * @version    SVN: $Id: photo_mainTopWidgetContainer.php 4645 2012-02-01 09:08:41Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/photo_mainBaseWidgetContainer.php');
@@ -344,10 +344,17 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 			if (!empty($category)) $this->categoryInfoArray[$parentCategory] = $category;
 		}
 		
-		// 検索画面作成
-		$fieldOutput = $this->createFieldOutput($searchTemplate);
+		// ##### 検索画面作成 #####
+		if (!empty(self::$_configArray[photo_mainCommonDef::CF_PHOTO_CATEGORY_PASSWORD]) && empty($this->authCategory)){// 画像カテゴリーのパスワード制限ありで参照可能カテゴリーがないとき
+			$fieldOutput = '';		// 検索画面なし
+		} else {
+			$fieldOutput = $this->createFieldOutput($searchTemplate);
+		}
 		if (!empty($fieldOutput)){
 			$this->tmpl->setAttribute('search_area', 'visibility', 'visible');		// 検索エリア表示
+			$this->tmpl->addVar("search_area", "html",	$fieldOutput);
+			$this->tmpl->addVar("search_area", "search_form_id",	photo_mainCommonDef::SEARCH_FORM_ID);		// 検索フォームのタグID
+			/*
 			$this->tmpl->addVar("_widget", "search_text_id",	photo_mainCommonDef::SEARCH_TEXT_ID);		// 検索用テキストフィールドのタグID
 			$this->tmpl->addVar("_widget", "search_button_id",	photo_mainCommonDef::SEARCH_BUTTON_ID);		// 検索用ボタンのタグID
 			$this->tmpl->addVar("_widget", "search_reset_id",	photo_mainCommonDef::SEARCH_RESET_ID);		// 検索エリアリセットボタンのタグID
@@ -355,8 +362,16 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 			$this->tmpl->addVar("_widget", "search_form_id",	photo_mainCommonDef::SEARCH_FORM_ID);		// 検索フォームのタグID
 			$this->tmpl->addVar("_widget", "keyword",	addslashes($keyword));		// 検索キーワード(Javascript部)
 			$this->tmpl->addVar("_widget", "sort",		$this->sortKey . '-' . $this->sortDirection);		// デフォルトのソート順
-			$this->tmpl->addVar("search_area", "html",	$fieldOutput);
-			$this->tmpl->addVar("search_area", "search_form_id",	photo_mainCommonDef::SEARCH_FORM_ID);		// 検索フォームのタグID
+			*/
+			$this->tmpl->setAttribute('search_script', 'visibility', 'visible');		// 検索エリア表示
+			$this->tmpl->addVar("search_script", "search_url", $this->getUrl($this->currentPageUrl));
+			$this->tmpl->addVar("search_script", "search_text_id",	photo_mainCommonDef::SEARCH_TEXT_ID);		// 検索用テキストフィールドのタグID
+			$this->tmpl->addVar("search_script", "search_button_id",	photo_mainCommonDef::SEARCH_BUTTON_ID);		// 検索用ボタンのタグID
+			$this->tmpl->addVar("search_script", "search_reset_id",	photo_mainCommonDef::SEARCH_RESET_ID);		// 検索エリアリセットボタンのタグID
+			$this->tmpl->addVar("search_script", "search_sort_id",	photo_mainCommonDef::SEARCH_SORT_ID);		// 検索エリアソート順のタグID
+			$this->tmpl->addVar("search_script", "search_form_id",	photo_mainCommonDef::SEARCH_FORM_ID);		// 検索フォームのタグID
+			$this->tmpl->addVar("search_script", "keyword",	addslashes($keyword));		// 検索キーワード(Javascript部)
+			$this->tmpl->addVar("search_script", "sort",		$this->sortKey . '-' . $this->sortDirection);		// デフォルトのソート順
 		}
 		
 		// 画面埋め込みデータ
@@ -365,7 +380,6 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 		$this->tmpl->addVar("_widget", "photo_detail_url", $this->getUrl($this->gEnv->getDefaultUrl(), true/*リンク用*/));		// 詳細画面へのリンク
 		$this->tmpl->addVar("_widget", "photo_detail_url_others", $urlParams);		// 詳細画面へのリンクの付加URLパラメータ
 		$this->tmpl->addVar("_widget", "ajax_url", $ajaxUrl);
-		$this->tmpl->addVar("_widget", "search_url", $this->getUrl($this->currentPageUrl));
 		$this->tmpl->addVar('_widget', 'raty_image_url', $this->getUrl($this->gEnv->getScriptsUrl() . self::RATY_IMAGE_DIR));	// jquery.raty画像パス
 	}
 	/**
