@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: s_blogTopWidgetContainer.php 4676 2012-02-13 05:11:22Z fishbone $
+ * @version    SVN: $Id: s_blogTopWidgetContainer.php 4753 2012-03-14 06:51:03Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/s_blogBaseWidgetContainer.php');
@@ -23,6 +23,11 @@ class s_blogTopWidgetContainer extends s_blogBaseWidgetContainer
 	private $categoryDb;	// DB接続オブジェクト
 	private $commentDb;			// DB接続オブジェクト
 	private $viewType;			// 表示タイプ
+	private $blogId;			// ブログID
+	private $categoryId;			// カテゴリーID
+	private $year;				// 表示する年
+	private $month;				// 表示する月
+	private $day;				// 表示する日
 	private $now;				// 現在日時
 	private $currentDay;		// 現在日
 	private $currentHour;		// 現在時間
@@ -128,7 +133,7 @@ class s_blogTopWidgetContainer extends s_blogBaseWidgetContainer
 		$month = $request->trimValueOf('month');		// 月指定
 		$day = $request->trimValueOf('day');		// 日指定
 		$keyword = $request->trimValueOf('keyword');// 検索キーワード
-		$category = $request->trimValueOf(M3_REQUEST_PARAM_CATEGORY_ID);		// カテゴリID
+		$categoryId = $request->trimValueOf(M3_REQUEST_PARAM_CATEGORY_ID);		// カテゴリID
 		$this->pageNo = $request->trimIntValueOf('page', '1');				// ページ番号
 		
 		// 表示タイプ取得
@@ -137,12 +142,16 @@ class s_blogTopWidgetContainer extends s_blogBaseWidgetContainer
 		if (!empty($keyword)){
 			$this->viewType = 'search';		// 表示タイプ(検索結果)
 			$this->blogId	= $blogId;		// ブログIDでの絞り込み
-		} else if (!empty($category)){
+		} else if (!empty($categoryId)){
 			$this->viewType = 'category';		// 表示タイプ(カテゴリ選択)
 			$this->blogId	= $blogId;		// ブログIDでの絞り込み
+			$this->categoryId = $categoryId;			// カテゴリーID
 		} else if (!empty($year) && !empty($month)){
 			$this->viewType = 'term';		// 表示タイプ(期間選択)
 			$this->blogId	= $blogId;		// ブログIDでの絞り込み
+			$this->year = $year;		// 年指定
+			$this->month = $month;		// 月指定
+			$this->day = $day;		// 日指定
 		} else if (!empty($entryId)){
 			$this->viewType = 'entry';		// 表示タイプ(記事選択)
 		} else if (!empty($blogId)){
@@ -151,6 +160,8 @@ class s_blogTopWidgetContainer extends s_blogBaseWidgetContainer
 		}
 
 		// テンプレート設定
+		$template = 'top_jquery.tmpl.html';
+				
 		switch ($this->viewType){
 			case 'search':		// 検索結果
 				$template = 'search.tmpl.html';
@@ -158,10 +169,14 @@ class s_blogTopWidgetContainer extends s_blogBaseWidgetContainer
 			case 'title':		// タイトル一覧
 				if (empty($this->jQueryViewStyle)){
 					$template = 'main.tmpl.html';
-				} else {
-					$template = 'top_jquery.tmpl.html';
+//				} else {
+//					$template = 'top_jquery.tmpl.html';
 				}
 				break;
+			case 'category':	// カテゴリー表示
+				break;
+			case 'term':	// 期間表示
+				break;
 			case 'entry':		// 記事表示
 				$template = 'entry_jquery.tmpl.html';
 				break;
@@ -337,30 +352,32 @@ class s_blogTopWidgetContainer extends s_blogBaseWidgetContainer
 	 */
 	function createCategoryList($request)
 	{
-				// 総数を取得
-				$totalCount = self::$_mainDb->getEntryItemsCountByCategory($this->now, $category, $this->langId);
+		// 総数を取得
+		$totalCount = self::$_mainDb->getEntryItemsCountByCategory($this->now, $this->categoryId, $this->langId);
 
-				// リンク文字列作成、ページ番号調整
-				$pageLink = $this->createPageLink($this->pageNo, $totalCount, $this->entryViewCount, $this->currentPageUrl . '&act=view&' . M3_REQUEST_PARAM_CATEGORY_ID . '=' . $category);
-				
-				// 記事一覧を表示
-				self::$_mainDb->getEntryItemsByCategory($this->entryViewCount, $this->pageNo, $this->now, $category, $this->langId, $this->entryViewOrder, array($this, 'itemsLoop'));
+		// リンク文字列作成、ページ番号調整
+		$pageLink = $this->createPageLink($this->pageNo, $totalCount, $this->entryViewCount, $this->currentPageUrl . '&' . M3_REQUEST_PARAM_CATEGORY_ID . '=' . $this->categoryId);
+		
+		// 記事一覧を表示
+		self::$_mainDb->getEntryItemsByCategory($this->entryViewCount, $this->pageNo, $this->now, $this->categoryId, $this->langId, $this->entryViewOrder, array($this, 'itemsLoop'));
 
-				// タイトルの設定
-				$ret = $this->categoryDb->getCategoryByCategoryId($category, $this->gEnv->getDefaultLanguage(), $row);
-				if ($ret) $this->title = $row['bc_name'];
-				
-				// ブログ記事データがないときはデータなしメッセージ追加
-				if ($this->isExistsViewData){
-					// ページリンクを埋め込む
-					if (!empty($pageLink)){
-						$this->tmpl->setAttribute('page_link', 'visibility', 'visible');		// リンク表示
-						$this->tmpl->addVar("page_link", "page_link", $pageLink);
-					}
-				} else {
-					$this->title = self::MESSAGE_NO_ENTRY_TITLE;
-					$this->message = self::MESSAGE_NO_ENTRY;			// ユーザ向けメッセージ
-				}
+		// タイトルの設定
+		$ret = $this->categoryDb->getCategoryByCategoryId($this->categoryId, $this->gEnv->getDefaultLanguage(), $row);
+		if ($ret) $this->title = $row['bc_name'];
+		
+		// ブログ記事データがないときはデータなしメッセージ追加
+		if ($this->isExistsViewData){
+			// ページリンクを埋め込む
+			if (!empty($pageLink)){
+				$this->tmpl->setAttribute('page_link', 'visibility', 'visible');		// リンク表示
+				$this->tmpl->addVar("page_link", "page_link", $pageLink);
+			}
+		} else {
+			$this->title = self::MESSAGE_NO_ENTRY_TITLE;
+			$this->message = self::MESSAGE_NO_ENTRY;			// ユーザ向けメッセージ
+		}
+		// 画面タイトル
+		$this->pageTitle = $this->title;
 	}
 	/**
 	 * 期間選択での一覧画面表示
@@ -370,62 +387,64 @@ class s_blogTopWidgetContainer extends s_blogBaseWidgetContainer
 	 */
 	function createTermList($request)
 	{
-				if (empty($day)){		// 月指定のとき
-					$startDt = $year . '/' . $month . '/1';
-					$endDt = $this->getNextMonth($year . '/' . $month) . '/1';
-					
-					// 総数を取得
-					$totalCount = self::$_mainDb->getEntryItemsCount($this->now, $startDt, $endDt, $this->langId);
+		if (empty($this->day)){		// 月指定のとき
+			$startDt = $this->year . '/' . $this->month . '/1';
+			$endDt = $this->getNextMonth($this->year . '/' . $this->month) . '/1';
+			
+			// 総数を取得
+			$totalCount = self::$_mainDb->getEntryItemsCount($this->now, $startDt, $endDt, $this->langId);
 
-					// リンク文字列作成、ページ番号調整
-					$pageLink = $this->createPageLink($this->pageNo, $totalCount, $this->entryViewCount, $this->currentPageUrl . '&act=view&year=' . $year . '&month=' . $month);
-				
-					// 記事一覧作成
-					self::$_mainDb->getEntryItems($this->entryViewCount, $this->pageNo, $this->now, $entryId, $startDt/*期間開始*/, $endDt/*期間終了*/, $this->langId, $this->entryViewOrder, array($this, 'itemsLoop'));
+			// リンク文字列作成、ページ番号調整
+			$pageLink = $this->createPageLink($this->pageNo, $totalCount, $this->entryViewCount, $this->currentPageUrl . '&year=' . $this->year . '&month=' . $this->month);
+		
+			// 記事一覧作成
+			self::$_mainDb->getEntryItems($this->entryViewCount, $this->pageNo, $this->now, $entryId, $startDt/*期間開始*/, $endDt/*期間終了*/, $this->langId, $this->entryViewOrder, array($this, 'itemsLoop'));
 
-					if ($this->isExistsViewData){
-						// ページリンクを埋め込む
-						if (!empty($pageLink)){
-							$this->tmpl->setAttribute('page_link', 'visibility', 'visible');		// リンク表示
-							$this->tmpl->addVar("page_link", "page_link", $pageLink);
-						}
-					}
-					// 年月の表示
-					$this->title = $year . '年 ' . $month . '月';
-					
-					// ブログ記事データがないときはデータなしメッセージ追加
-					if (!$this->isExistsViewData){
-						$this->message = self::MESSAGE_NO_ENTRY;			// ユーザ向けメッセージ
-					}
-				} else {
-					$startDt = $year . '/' . $month . '/' . $day;
-					$endDt = $this->getNextDay($year . '/' . $month . '/' . $day);
-					
-					// 総数を取得
-					$totalCount = self::$_mainDb->getEntryItemsCount($this->now, $startDt, $endDt, $this->langId);
-
-					// リンク文字列作成、ページ番号調整
-					$pageLink = $this->createPageLink($this->pageNo, $totalCount, $this->entryViewCount, $this->currentPageUrl . '&act=view&year=' . $year . '&month=' . $month . '&day=' . $day);
-					
-					// 記事一覧作成
-					self::$_mainDb->getEntryItems($this->entryViewCount, $this->pageNo, $this->now, $entryId, $startDt/*期間開始*/, $endDt/*期間終了*/, $this->langId, $this->entryViewOrder, array($this, 'itemsLoop'));
-					
-					if ($this->isExistsViewData){
-						// ページリンクを埋め込む
-						if (!empty($pageLink)){
-							$this->tmpl->setAttribute('page_link', 'visibility', 'visible');		// リンク表示
-							$this->tmpl->addVar("page_link", "page_link", $pageLink);
-						}
-					}
-					
-					// 年月日の表示
-					$this->title = $year . '年 ' . $month . '月 ' . $day . '日';
-					
-					// ブログ記事データがないときはデータなしメッセージ追加
-					if (!$this->isExistsViewData){
-						$this->message = self::MESSAGE_NO_ENTRY;			// ユーザ向けメッセージ
-					}
+			if ($this->isExistsViewData){
+				// ページリンクを埋め込む
+				if (!empty($pageLink)){
+					$this->tmpl->setAttribute('page_link', 'visibility', 'visible');		// リンク表示
+					$this->tmpl->addVar("page_link", "page_link", $pageLink);
 				}
+			}
+			// 年月の表示
+			$this->title = $this->year . '年 ' . $this->month . '月';
+			
+			// ブログ記事データがないときはデータなしメッセージ追加
+			if (!$this->isExistsViewData){
+				$this->message = self::MESSAGE_NO_ENTRY;			// ユーザ向けメッセージ
+			}
+		} else {
+			$startDt = $this->year . '/' . $this->month . '/' . $this->day;
+			$endDt = $this->getNextDay($this->year . '/' . $this->month . '/' . $this->day);
+			
+			// 総数を取得
+			$totalCount = self::$_mainDb->getEntryItemsCount($this->now, $startDt, $endDt, $this->langId);
+
+			// リンク文字列作成、ページ番号調整
+			$pageLink = $this->createPageLink($this->pageNo, $totalCount, $this->entryViewCount, $this->currentPageUrl . '&year=' . $this->year . '&month=' . $this->month . '&day=' . $this->day);
+			
+			// 記事一覧作成
+			self::$_mainDb->getEntryItems($this->entryViewCount, $this->pageNo, $this->now, $entryId, $startDt/*期間開始*/, $endDt/*期間終了*/, $this->langId, $this->entryViewOrder, array($this, 'itemsLoop'));
+			
+			if ($this->isExistsViewData){
+				// ページリンクを埋め込む
+				if (!empty($pageLink)){
+					$this->tmpl->setAttribute('page_link', 'visibility', 'visible');		// リンク表示
+					$this->tmpl->addVar("page_link", "page_link", $pageLink);
+				}
+			}
+			
+			// 年月日の表示
+			$this->title = $this->year . '年 ' . $this->month . '月 ' . $this->day . '日';
+			
+			// ブログ記事データがないときはデータなしメッセージ追加
+			if (!$this->isExistsViewData){
+				$this->message = self::MESSAGE_NO_ENTRY;			// ユーザ向けメッセージ
+			}
+		}
+		// 画面タイトル
+		$this->pageTitle = $this->title;
 	}
 	/**
 	 * 記事画面表示
@@ -472,11 +491,11 @@ class s_blogTopWidgetContainer extends s_blogBaseWidgetContainer
 			if (!empty($this->receiveComment)){
 				$this->tmpl->setAttribute('entry_footer', 'visibility', 'visible');		// コメントへのリンク
 			}
-			if (!empty($category)){				// カテゴリー指定のとき
+/*			if (!empty($category)){				// カテゴリー指定のとき
 
 			} else if (!empty($year) && !empty($month)){
 
-			}
+			}*/
 			$this->pageTitle = $this->title;		// カテゴリー名を画面タイトルにする
 		} else if ($act == 'checkcomment'){		// コメント確認のとき
 			// 入力チェック
